//
//  ContinuityViewController.swift
//  ContinuityCameraPlayground
//
//  Created by Thomas Zoechling on 17.10.18.
//  Copyright © 2018 Peakstep. All rights reserved.
//

import Cocoa

class ContinuityViewController: NSViewController, NSServicesMenuRequestor {

    @IBOutlet weak var imageView: NSImageView!

    override func validRequestor(forSendType sendType: NSPasteboard.PasteboardType?, returnType: NSPasteboard.PasteboardType?) -> Any? {
        if let pasteboardType = returnType,
            NSImage.imageTypes.contains(pasteboardType.rawValue) {
            return self
        } else {
            return super.validRequestor(forSendType: sendType, returnType: returnType)
        }
    }

    func readSelection(from pasteboard: NSPasteboard) -> Bool {
        guard pasteboard.canReadItem(withDataConformingToTypes: NSImage.imageTypes) else { return false }
        guard let image = NSImage(pasteboard: pasteboard) else { return false }

        self.imageView.image = image
        return true
    }

    @IBAction func showMenu(_ sender: NSButton) {
        guard let menu = sender.menu else { return }
        guard let event = NSApplication.shared.currentEvent else { return }

        // AppKit uses the Responder Chain to figure out where to insert the Continuity Camera menu items.
        // So making ourselves `firstResponder` here is important.
        self.view.window?.makeFirstResponder(self)
        NSMenu.popUpContextMenu(menu, with: event, for: sender)
    }
}
